pub struct CmdServer { /* private fields */ }Expand description
A Wand server implementation that runs an external command to start the server.
Fields
src: Where to get the executable/source code for the serversetup_cmd: Command to set up and run the serversetup_args: Arguments for the setup commandlocal_folder: Local folder to extract the source code, default is $HOME/wand_serverchild: The child process running the server
Implementations